@@ -24,10 +24,10 @@ class ProgressBarBase(Callback):
 
             def __init__(self):
                 super().__init__()  # don't forget this :)
-                self.enabled = True
+                self.enable = True
 
             def disable(self):
-                self.enableenabled = False
+                self.enable = False
 
             def on_batch_end(self, trainer, pl_module):
                 super().on_batch_end(trainer, pl_module)  # don't forget this :)
@@ -93,7 +93,7 @@ class ProgressBarBase(Callback):
         """
         trainer = self.trainer
         total_val_batches = 0
-        if trainer.fast_dev_run:
+        if trainer.fast_dev_run and trainer.val_dataloaders is not None:
             total_val_batches = len(trainer.val_dataloaders)
         elif not self.trainer.disable_validation:
             is_val_epoch = (trainer.current_epoch + 1) % trainer.check_val_every_n_epoch == 0
