@@ -3,8 +3,8 @@ TensorBoard
 -----------
 """
 
-import csv
 import os
+import yaml
 from argparse import Namespace
 from typing import Optional, Dict, Union, Any
 from warnings import warn
@@ -14,6 +14,7 @@ from pkg_resources import parse_version
 from torch.utils.tensorboard import SummaryWriter
 
 from pytorch_lightning import _logger as log
+from pytorch_lightning.core.saving import save_hparams_to_yaml
 from pytorch_lightning.loggers.base import LightningLoggerBase
 from pytorch_lightning.utilities import rank_zero_only
 
@@ -42,7 +43,7 @@ class TensorBoardLogger(LightningLoggerBase):
         \**kwargs: Other arguments are passed directly to the :class:`SummaryWriter` constructor.
 
     """
-    NAME_CSV_TAGS = 'meta_tags.csv'
+    NAME_HPARAMS_FILE = 'hparams.yaml'
 
     def __init__(self,
                  save_dir: str,
@@ -55,7 +56,7 @@ class TensorBoardLogger(LightningLoggerBase):
         self._version = version
 
         self._experiment = None
-        self.tags = {}
+        self.hparams = {}
         self._kwargs = kwargs
 
     @property
@@ -104,8 +105,13 @@ class TensorBoardLogger(LightningLoggerBase):
     def log_hyperparams(self, params: Union[Dict[str, Any], Namespace],
                         metrics: Optional[Dict[str, Any]] = None) -> None:
         params = self._convert_params(params)
+
+        # store params to output
+        self.hparams.update(params)
+
+        # format params into the suitable for tensorboard
         params = self._flatten_dict(params)
-        sanitized_params = self._sanitize_params(params)
+        params = self._sanitize_params(params)
 
         if parse_version(torch.__version__) < parse_version("1.3.0"):
             warn(
@@ -115,16 +121,18 @@ class TensorBoardLogger(LightningLoggerBase):
             )
         else:
             from torch.utils.tensorboard.summary import hparams
+
             if metrics is None:
                 metrics = {}
-            exp, ssi, sei = hparams(sanitized_params, metrics)
+            exp, ssi, sei = hparams(params, metrics)
             writer = self.experiment._get_file_writer()
             writer.add_summary(exp)
             writer.add_summary(ssi)
             writer.add_summary(sei)
 
-        # some alternative should be added
-        self.tags.update(sanitized_params)
+            if metrics:
+                # necessary for hparam comparison with metrics
+                self.log_metrics(metrics)
 
     @rank_zero_only
     def log_metrics(self, metrics: Dict[str, float], step: Optional[int] = None) -> None:
@@ -147,15 +155,10 @@ class TensorBoardLogger(LightningLoggerBase):
             dir_path = self.save_dir
 
         # prepare the file path
-        meta_tags_path = os.path.join(dir_path, self.NAME_CSV_TAGS)
+        hparams_file = os.path.join(dir_path, self.NAME_HPARAMS_FILE)
 
         # save the metatags file
-        with open(meta_tags_path, 'w', newline='') as csvfile:
-            fieldnames = ['key', 'value']
-            writer = csv.DictWriter(csvfile, fieldnames=fieldnames)
-            writer.writerow({'key': 'key', 'value': 'value'})
-            for k, v in self.tags.items():
-                writer.writerow({'key': k, 'value': v})
+        save_hparams_to_yaml(hparams_file, self.hparams)
 
     @rank_zero_only
     def finalize(self, status: str) -> None:
