@@ -46,8 +46,8 @@ def _has_len(dataloader: DataLoader) -> bool:
     try:
         # try getting the length
         if len(dataloader) == 0:
-            raise ValueError('Dataloader returned 0 length. Please make sure'
-                             ' that your Dataloader atleast returns 1 batch')
+            raise ValueError('`Dataloader` returned 0 length.'
+                             ' Please make sure that your Dataloader at least returns 1 batch')
         return True
     except TypeError:
         return False
@@ -78,7 +78,7 @@ class TrainerDataLoadingMixin(ABC):
     replace_sampler_ddp: bool
 
     @abstractmethod
-    def is_overriden(self, *args):
+    def is_overridden(self, *args):
         """Warning: this is just empty shell for code implemented in other class."""
 
     def _percent_range_check(self, name: str) -> None:
@@ -111,8 +111,8 @@ class TrainerDataLoadingMixin(ABC):
         if not is_dataloader or is_iterable_ds:
             return dataloader
         need_dist_sampler = (self.use_ddp or self.use_ddp2 or self.use_horovod or self.use_tpu)
-        if self.replace_sampler_ddp and need_dist_sampler:
 
+        if self.replace_sampler_ddp and need_dist_sampler:
             skip_keys = ['sampler', 'batch_sampler', 'dataset_kind']
 
             dl_args = {
@@ -137,7 +137,7 @@ class TrainerDataLoadingMixin(ABC):
                 }
                 sampler = DistributedSampler(
                     dataloader.dataset,
-                    num_replicas=world_size.get(self.distributed_backend, 0),
+                    num_replicas=world_size[self.distributed_backend],
                     rank=self.proc_rank,
                 )
 
@@ -186,10 +186,10 @@ class TrainerDataLoadingMixin(ABC):
                     self.val_check_batch = float('inf')
                 else:
                     raise MisconfigurationException(
-                        'When using an infinite DataLoader (e.g. with an IterableDataset or when '
-                        'DataLoader does not implement `__len__`) for `train_dataloader`, '
-                        '`Trainer(val_check_interval)` must be `1.0` or an int. An int k specifies '
-                        'checking validation every k training batches.')
+                        'When using an infinite DataLoader (e.g. with an IterableDataset'
+                        ' or when DataLoader does not implement `__len__`) for `train_dataloader`,'
+                        ' `Trainer(val_check_interval)` must be `1.0` or an int. An int k specifies'
+                        ' checking validation every k training batches.')
             else:
                 self._percent_range_check('val_check_interval')
 
@@ -218,8 +218,11 @@ class TrainerDataLoadingMixin(ABC):
                     f'Your {mode}_dataloader has shuffle=True, it is best practice to turn'
                     ' this off for validation and test dataloaders.')
 
+        if any([dl is None for dl in dataloaders]):
+            rank_zero_warn("One of given dataloaders is None and it will be skipped.")
+
         # add samplers
-        dataloaders = [self.auto_add_sampler(dl, train=False) for dl in dataloaders if dl]
+        dataloaders = [self.auto_add_sampler(dl, train=False) for dl in dataloaders if dl is not None]
 
         num_batches = 0
 
@@ -240,9 +243,9 @@ class TrainerDataLoadingMixin(ABC):
                 num_batches = int(num_batches * percent_check)
             elif percent_check not in (0.0, 1.0):
                 raise MisconfigurationException(
-                    'When using an infinite DataLoader (e.g. with an IterableDataset or when '
-                    f'DataLoader does not implement `__len__`) for `{mode}_dataloader`, '
-                    f'`Trainer({mode}_percent_check)` must be `0.0` or `1.0`.')
+                    'When using an infinite DataLoader (e.g. with an IterableDataset'
+                    f' or when DataLoader does not implement `__len__`) for `{mode}_dataloader`,'
+                    f' `Trainer({mode}_percent_check)` must be `0.0` or `1.0`.')
         return num_batches, dataloaders
 
     def reset_val_dataloader(self, model: LightningModule) -> None:
@@ -251,8 +254,8 @@ class TrainerDataLoadingMixin(ABC):
         Args:
             model: The current `LightningModule`
         """
-        if self.is_overriden('validation_step'):
-            self.num_val_batches, self.val_dataloaders =\
+        if self.is_overridden('validation_step'):
+            self.num_val_batches, self.val_dataloaders = \
                 self._reset_eval_dataloader(model, 'val')
 
     def reset_test_dataloader(self, model) -> None:
@@ -261,7 +264,7 @@ class TrainerDataLoadingMixin(ABC):
         Args:
             model: The current `LightningModule`
         """
-        if self.is_overriden('test_step'):
+        if self.is_overridden('test_step'):
             self.num_test_batches, self.test_dataloaders =\
                 self._reset_eval_dataloader(model, 'test')
 
