@@ -11,7 +11,7 @@ class TrainerModelHooksMixin(ABC):
         f_op = getattr(model, f_name, None)
         return callable(f_op)
 
-    def is_overriden(self, method_name: str, model: LightningModule = None) -> bool:
+    def is_overridden(self, method_name: str, model: LightningModule = None) -> bool:
         if model is None:
             model = self.get_model()
         super_object = LightningModule
@@ -30,10 +30,10 @@ class TrainerModelHooksMixin(ABC):
             # cannot pickle __code__ so cannot verify if PatchDataloader
             # exists which shows dataloader methods have been overwritten.
             # so, we hack it by using the string representation
-            is_overriden = instance_attr.patch_loader_code != str(super_attr.__code__)
+            is_overridden = instance_attr.patch_loader_code != str(super_attr.__code__)
         else:
-            is_overriden = instance_attr.__code__ is not super_attr.__code__
-        return is_overriden
+            is_overridden = instance_attr.__code__ is not super_attr.__code__
+        return is_overridden
 
     def has_arg(self, f_name, arg_name):
         model = self.get_model()
