@@ -81,7 +81,7 @@ class TrainerOptimizersMixin(ABC):
                 ' * multiple outputs, dictionaries as described with an optional `frequency` key (int)')
 
     def configure_schedulers(self, schedulers: list):
-        # Convert each scheduler into dict sturcture with relevant information
+        # Convert each scheduler into dict structure with relevant information
         lr_schedulers = []
         default_config = {'interval': 'epoch',  # default every epoch
                           'frequency': 1,  # default every epoch/batch
@@ -90,7 +90,7 @@ class TrainerOptimizersMixin(ABC):
         for scheduler in schedulers:
             if isinstance(scheduler, dict):
                 if 'scheduler' not in scheduler:
-                    raise ValueError(f'Lr scheduler should have key `scheduler`',
+                    raise ValueError('Lr scheduler should have key `scheduler`',
                                      ' with item being a lr scheduler')
                 scheduler['reduce_on_plateau'] = isinstance(
                     scheduler['scheduler'], optim.lr_scheduler.ReduceLROnPlateau)
